==> core_commands-1.4.0-py3-none-any.whl: core_commands/cmd/cmd.py <==
from ..bin.cmd import cmd

from .arp import arp
from .assoc import assoc
from .attrib import attrib
from .auditpol import auditpol
from .bcdboot import bcdboot
from .bcdedit import bcdedit
from .bitsadmin import bitsadmin
from .BREAK import BREAK
from .cacls import cacls
from .call import call
from .cd import cd
from .certreq import certreq
from .certutil import certutil
from .change import change
from .changepk import changepk
from .chcp import chcp
from .chdir import chdir
from .chkdsk import chkdsk
from .chkntfs import chkntfs
from .choice import choice
from .cipher import cipher
from .cleanmgr import cleanmgr
from .clip import clip
from .cls import cls
from .cmdkey import cmdkey
from .color import color
from .cmd import CMD
from .comp import comp
from .compact import compact
from .convert import convert
from .copy import copy
from .curl import curl
from .date import date
from .defrag import defrag
from .DEL import DEL
from .dir import dir
from .diskpart import diskpart
from .dism import dism
from .displayswitch import displayswitch
from .doskey import doskey
from .driverquery import driverquery
from .dsregcmd import dsregcmd
from .echo import echo
from .endlocal import endlocal
from .erase import erase
from .esentutl import esentutl
from .eventcreate import eventcreate
from .exit import exit
from .expand import expand
from .explorer import explorer
from .fc import fc
from .findstr import findstr
from .fltmc import fltmc
from .FOR import FOR
from .forfiles import forfiles
from .format import format
from .fsutil import fsutil
from .ftp import ftp
from .ftype import ftype
from .getmac import getmac
from .goto import goto
from .gpresult import gpresult
from .gpupdate import gpupdate
from .help import help
from .hostname import hostname
from .icacls import icacls
from .iexpress import iexpress
from .IF import IF
from .ipconfig import ipconfig
from .klist import klist
from .label import label
from .lodctr import lodctr
from .logman import logman
from .logoff import logoff
from .makecab import makecab
from .manage_bde import manage_bde
from .mbr2gpt import mbr2gpt
from .md import md
from .mkdir import mkdir
from .mklink import mklink
from .mode import mode
from .more import more
from .mountvol import mountvol
from .move import move
from .moveuser import moveuser
from .msg import msg
from .msiexec import msiexec
from .msinfo32 import msinfo32
from .mstsc import mstsc
from .nbtstat import nbtstat
from .net import net
from .netsh import netsh
from .netstat import netstat
from .nltest import nltest
from .nslookup import nslookup
from .openfiles import openfiles
from .path import path
from .pathping import pathping
from .pause import pause
from .ping import ping
from .pktmon import pktmon
from .pnputil import pnputil
from .popd import popd
from .powercfg import powercfg
from .PRINT import PRINT
from .prompt import prompt
from .pushd import pushd
from .qappsrv import qappsrb
from .qprocess import qprocess
from .quser import quser
from .qwinsta import qwinsta
from .rasdial import rasdial
from .rasphone import rasphone
from .rd import rd
from .reagentc import reagentc
from .recover import recover
from .reg import reg
from .regedit import regedit
from .regini import regini
from .regsvr32 import regsvr32
from .ren import ren
from .replace import replace
from .reset import reset
from .rmdir import rmdir
from .rmtshare import rmtshare
from .robocopy import robocopy
from .route import route
from .runas import runas
from .rundll32 import rundll32
from .sc import sc
from .schtasks import schtasks
from .scriptrunner import scriptrunner
from .set import set
from .setlocal import setlocal
from .setspn import setspn
from .setx import setx
from .sfc import sfc
from .shift import shift
from .shutdown import shutdown
from .sleep import sleep
from .slmgr import slmgr
from .sort import sort
from .ssh import ssh
from .start import start
from .subst import subst
from .systeminfo import systeminfo
from .takeown import takeown
from .tar import tar
from .taskkill import taskkill
from .tasklist import tasklist
from .time import time
from .timeout import timeout
from .title import title
from .tracert import tracert
from .tree import tree
from .tsdiscon import tsdiscon
from .tskill import tskill
from .type import type
from .typeperf import typeperf
from .tzutil import tzutil
from .ver import ver
from .verify import verify
from .vol import vol
from .vssadmin import vssadmin
from .w32tm import w32tm
from .waitfor import waitfor
from .wbadmin import wbadmin
from .wecutil import wecutil
from .wevtutil import wevtutil
from .where import where
from .whoami import whoami
from .windiff import windiff
from .winget import winget
from .winmgmt import winmgmt
from .winrm import winrm
from .winrs import winrs
from .wmic import wmic
from .wpr import wpr
from .wt import wt
from .wuauclt import wuauclt
from .wusa import wusa
from .xcopy import xcopy

def CMD(arguments=None):
    # https://ss64.com/nt/cmd.html
    return cmd(arguments)
    pass

==> core_commands-1.4.6-py3-none-any.whl: core_commands/cmd/cmd.py <==
from ..bin.cmd import cmd

from .arp import arp
from .assoc import assoc
from .attrib import attrib
from .auditpol import auditpol
from .bcdboot import bcdboot
from .bcdedit import bcdedit
from .bitsadmin import bitsadmin
from .BREAK import BREAK
from .cacls import cacls
from .call import call
from .cd import cd
from .certreq import certreq
from .certutil import certutil
from .change import change
from .changepk import changepk
from .chcp import chcp
from .chdir import chdir
from .chkdsk import chkdsk
from .chkntfs import chkntfs
from .choice import choice
from .cipher import cipher
from .cleanmgr import cleanmgr
from .clip import clip
from .cls import cls
from .cmdkey import cmdkey
from .color import color
from .comp import comp
from .compact import compact
from .convert import convert
from .copy import copy
from .curl import curl
from .date import date
from .defrag import defrag
from .DEL import DEL
from .dir import dir
from .diskpart import diskpart
from .dism import dism
from .displayswitch import displayswitch
from .doskey import doskey
from .driverquery import driverquery
from .dsregcmd import dsregcmd
from .echo import echo
from .endlocal import endlocal
from .erase import erase
from .esentutl import esentutl
from .eventcreate import eventcreate
from .exit import exit # TODO: cambiarlo a EXIT ya que exit es una funcion de python
from .expand import expand
from .explorer import explorer
from .fc import fc
from .findstr import findstr
from .fltmc import fltmc
from .FOR import FOR
from .forfiles import forfiles
from .format import format
from .fsutil import fsutil
from .ftp import ftp
from .ftype import ftype
from .getmac import getmac
from .goto import goto
from .gpresult import gpresult
from .gpupdate import gpupdate
from .help import help
from .hostname import hostname
from .icacls import icacls
from .iexpress import iexpress
from .IF import IF
from .ipconfig import ipconfig
from .klist import klist
from .label import label
from .lodctr import lodctr
from .logman import logman
from .logoff import logoff
from .makecab import makecab
from .manage_bde import manage_bde
from .mbr2gpt import mbr2gpt
from .md import md
from .mkdir import mkdir
from .mklink import mklink
from .mode import mode
from .more import more
from .mountvol import mountvol
from .move import move
from .moveuser import moveuser
from .msg import msg
from .msiexec import msiexec
from .msinfo32 import msinfo32
from .mstsc import mstsc
from .nbtstat import nbtstat
from .net import net
from .netsh import netsh
from .netstat import netstat
from .nltest import nltest
from .nslookup import nslookup
from .openfiles import openfiles
from .path import path
from .pathping import pathping
from .pause import pause
from . import ping
from .pktmon import pktmon
from .pnputil import pnputil
from .popd import popd
from .powercfg import powercfg
from .PRINT import PRINT
from .prompt import prompt
from .pushd import pushd
from .qappsrv import qappsrb
from .qprocess import qprocess
from .quser import quser
from .qwinsta import qwinsta
from .rasdial import rasdial
from .rasphone import rasphone
from .rd import rd
from .reagentc import reagentc
from .recover import recover
from .reg import reg
from .regedit import regedit
from .regini import regini
from .regsvr32 import regsvr32
from .ren import ren
from .replace import replace
from .reset import reset
from .rmdir import rmdir
from .rmtshare import rmtshare
from .robocopy import robocopy
from .route import route
from .runas import runas
from .rundll32 import rundll32
from .sc import sc
from .schtasks import schtasks
from .scriptrunner import scriptrunner
from .set import set
from .setlocal import setlocal
from .setspn import setspn
from .setx import setx
from .sfc import sfc
from .shift import shift
from .shutdown import shutdown
from .sleep import sleep
from .slmgr import slmgr
from .sort import sort
from .ssh import ssh
from .start import start
from .subst import subst
from .systeminfo import systeminfo
from .takeown import takeown
from .tar import tar
from .taskkill import taskkill
from .tasklist import tasklist
from .time import time
from .timeout import timeout
from .title import title
from .tracert import tracert
from .tree import tree
from .tsdiscon import tsdiscon
from .tskill import tskill
from .type import type
from .typeperf import typeperf
from .tzutil import tzutil
from .ver import ver
from .verify import verify
from .vol import vol
from .vssadmin import vssadmin
from .w32tm import w32tm
from .waitfor import waitfor
from .wbadmin import wbadmin
from .wecutil import wecutil
from .wevtutil import wevtutil
from .where import where
from .whoami import whoami
from .windiff import windiff
from .winget import winget
from .winmgmt import winmgmt
from .winrm import winrm
from .winrs import winrs
from .wmic import wmic
from .wpr import wpr
from .wt import wt
from .wuauclt import wuauclt
from .wusa import wusa
from .xcopy import xcopy
